@@ -14,8 +14,8 @@
 #' to the dataPreparators.
 #' @param buildModelAlgo string, model name to be used. All possible preparators
 #' are listed via: getSupportedModels().
-#' @param buildModelControl list, control-list containing all additional parameters that shall be passed
-#' to the modelling algo.
+#' @param buildForecastModelControl list, control-list containing all additional parameters that shall be passed to forecast modeling algorithm
+#' @param buildNeuralNetModelControl list, control-list containing all additional parameters that shall be passed to the neuralnet modeling algorithm
 #' @param postProcessors string or vector of strings, that defines which postProcessors to use.
 #' Lists are not accepted. Usage Example: postProcessors = "bedAlgo" results in the usage of
 #' bed as a event postProcessing tool. All possible preparators are listed via:
@@ -37,16 +37,19 @@
 #' @examples
 #'
 #' ## build a simple event detection model with standard configuration
-#' x <- stationBData[1:2000,-1]
-#' buildEDModel(x)
+#' x <- stationBData[100:200,-1]
+#' buildEDModel(x,ignoreVarianceWarning = TRUE)
 #'
 #' ## Set up a more complex event detection model defining some additional configuration
-#' buildEDModel(x, dataPrepators = "ImputeTSMean", buildModelAlgo = "ForecastArima")
+#' buildEDModel(x, buildModelAlgo = "ForecastArima",ignoreVarianceWarning = TRUE)
+#'
+#'  ## Set up a multivariate neuralnetwork model
+#' buildEDModel(x, buildModelAlgo = "NeuralNetwork",ignoreVarianceWarning = TRUE)
 buildEDModel <- function(x,
                          dataPrepators = "ImputeTSInterpolation",
                          dataPreparationControl = list(),
                          buildModelAlgo = "ForecastETS",
-                         buildModelControl = list(),
+                         buildForecastModelControl = list(),buildNeuralNetModelControl = list(),
                          postProcessors = "bedAlgo",
                          postProcessorControl = list(),
                          ignoreVarianceWarning = FALSE,
@@ -59,9 +62,14 @@ buildEDModel <- function(x,
     dataPreparationControl <- con
     rm(con)
 
-    con <- getDefaultModelControl()
-    con[names(buildModelControl)] <- buildModelControl
-    buildModelControl <- con
+    con <- getDefaultForecastModelControl()
+    con[names(buildForecastModelControl)] <- buildForecastModelControl
+    buildForecastModelControl <- con
+    rm(con)
+
+    con <- getDefaultNeuralNetModelControl()
+    con[names(buildNeuralNetModelControl)] <- buildNeuralNetModelControl
+    buildNeuralNetModelControl <- con
     rm(con)
 
     con <- getDefaultPostControl()
@@ -159,7 +167,13 @@ buildEDModel <- function(x,
 
 
     ## Apply Normalization --------------
-    ##
+
+    ## Added by Sowmya
+    ## Define minmax normalization method for neural network models
+
+    minmax_normalize <- function(x) {
+      return ((x - min(x,na.rm = TRUE)) / (max(x,na.rm = TRUE) - min(x,na.rm = TRUE)))
+    }
     ## Variables which have no variance will be removed!
     ## A warning is generated if this happens
     ##
@@ -178,7 +192,21 @@ buildEDModel <- function(x,
             }
         removedVarNames <- list(colnames(x)[zeroVarianceVars])
         x <- x[,!zeroVarianceVars]
+# Added by Sowmya
+        min_x <- NULL
+        max_x <- NULL
+            if(buildModelAlgo=="NeuralNetwork"){
+
+            for(i in 1:ncol(x)){
+              min_x <- c(min_x,min(x[,i],na.rm = TRUE))
+              max_x <- c(max_x,max(x[,i],na.rm = TRUE))
+            }
+
+            x <- as.data.frame(lapply(x, minmax_normalize))
+        }
+        else{
         x <- scale(x)
+        }
     }
 
     ## -----------------------
@@ -188,9 +216,14 @@ buildEDModel <- function(x,
     ## -----------------------
     if(buildModelAlgo %in% allSupportedModels$supportedUnivariateForeCastModels){
         modelStr <- substr(buildModelAlgo, nchar("Forecast") + 1, nchar(buildModelAlgo))
-        model <- model_UnivariateForecast(x, modelStr, buildModelControl)
+        model <- model_UnivariateForecast(x, modelStr, buildForecastModelControl)
     }
     #%TODO Missing Add general code call for type 'other' models
+    ## Added by Sowmya --- Multivariate NeuralNetwork model
+    if(buildModelAlgo %in% allSupportedModels$supportedMultivariateModels){
+
+      model <- model_NeuralNetwork(x, buildNeuralNetModelControl)
+    }
 
     model$oldModel <- oldModel
 
@@ -216,14 +249,24 @@ buildEDModel <- function(x,
     ##
     ## ControlLists can then be called by each submodule
     model$userConfig$dataPreparationControl <- dataPreparationControl
-    model$userConfig$buildModelControl <- buildModelControl
+    model$userConfig$buildNeuralNetModelControl <- buildNeuralNetModelControl
+    model$userConfig$buildForecastModelControl <- buildForecastModelControl
     model$userConfig$postProcessorControl <- postProcessorControl
 
     ## Add Normalization Scale Factors to model ----
     ##
+    if(buildModelAlgo!="NeuralNetwork")
+      {
+    model$buildModelAlgo <- "UnivariateForecast"
     model$normalization$scaleCenter <- attr(x,"scaled:center")
     model$normalization$scaleSD <- attr(x,"scaled:scale")
-
+    }
+    if((buildModelAlgo=="NeuralNetwork") && (isTRUE(dataPreparationControl$useNormalization)))
+    {
+    model$normalization$min_x <-min_x
+    model$normalization$max_x <-max_x
+    model$buildModelAlgo <- "NeuralNetwork"
+    }
     ## Add remark for removed variables
     ##
     model$excludedVariables <- removedVarNames
