@@ -1,14 +1,14 @@
 #' detectEvents in a given data.frame
 #'
 #' detectEvents builds a prediction model (edObject) on the first 'windowSize' points of the given data x.
-#' The next nIterationRefit data-points are classified as Event or not.
+#' The next 'nIterationRefit' data-points are classified as 'Event' or not.
 #' The window is moved iteratively and the next models are fitted.
-#' The first windowSize points will always be classified as no Event and should only contain 'clean' data
+#' The first 'windowSize' points will always be classified as no Event and should only contain 'clean' data
 #'
 #' @param x data.frame, data which shall be classified as event or not
 #' @param windowSize amount of data points to consider in each prediction model
 #' @param nIterationsRefit amount of points into the future which will be predicted without fitting a new model.
-#' E.g. if nIterationsRefit = 5 then the next five dataPoints are classified without refitting.
+#' E.g. if nIterationsRefit = 10 then the next five dataPoints are classified without refitting.
 #' @param verbosityLevel Print output of function progress. 0 -> No output,
 #' 1 -> every 100th model building iteration, 2 -> every 10th, 3 -> every iteration
 #' @param dataPrepators string or vector of strings, that defines which preparators to use.
@@ -19,8 +19,8 @@
 #' to the dataPreparators.
 #' @param buildModelAlgo string, model name to be used. All possible preparators
 #' are listed via: getSupportedModels().
-#' @param buildModelControl list, control-list containing all additional parameters that shall be passed
-#' to the modelling algo.
+#' @param buildForecastModelControl list, control-list containing all additional parameters that shall be passed to the  forecast modelling algo.
+#' @param buildNeuralNetModelControl list, control-list containing all additional parameters that shall be passed to the neuralnet modelling algo.
 #' @param postProcessors string or vector of strings, that defines which postProcessors to use.
 #' Lists are not accepted. Usage Example: postProcessors = "bedAlgo" results in the usage of
 #' bed as a event postProcessing tool. All possible preparators are listed via:
@@ -38,24 +38,29 @@
 #' def <- detectEvents(x = stationBData[1:100,-1])
 #'
 #' \donttest{
-#' ## Only refit the model after every 50th new datapoint,
+#' ## Refit the model at every new datapoint,
 #' ## have someoutput with verbosityLevel = 2 and ignore
 #' ## the variance warning
-#' ed <- detectEvents(stationBData[1000:2000,-1],nIterationsRefit = 50,
+#' ed <- detectEvents(stationBData[1:110,-1],nIterationsRefit = 1,
 #'                    verbosityLevel = 2,ignoreVarianceWarning = TRUE)
 #'
 #' ## Switch to another model: Arima
-#' ed2 <- detectEvents(stationBData[1000:2000,-1],nIterationsRefit = 50,
-#'                     verbosityLevel = 2,ignoreVarianceWarning = TRUE,
-#'                     buildModelAlgo = "ForecastArima")}
+#' ed2 <- detectEvents(stationBData[1:110,-1],nIterationsRefit = 1,
+#'                     verbosityLevel = 0,ignoreVarianceWarning = TRUE,
+#'                     buildModelAlgo = "ForecastArima")
+#'
+#'    ## Switch to multivariate model: NeuralNetwork
+#' ed3 <- detectEvents(stationBData[1:110,-1],nIterationsRefit = 1, buildModelAlgo = "NeuralNetwork")
+#'                     }
 detectEvents <- function(x,
                          windowSize = 100,
-                         nIterationsRefit = 50,
+                         nIterationsRefit = 1,
                          verbosityLevel = 0,
                          dataPrepators = "ImputeTSInterpolation",
                          dataPreparationControl = list(),
                          buildModelAlgo = "ForecastETS",
-                         buildModelControl = list(),
+                         buildForecastModelControl = list(),
+                         buildNeuralNetModelControl = list(),
                          postProcessors = "bedAlgo",
                          postProcessorControl = list(),
                          ignoreVarianceWarning = TRUE) {
@@ -110,7 +115,9 @@ detectEvents <- function(x,
     if(verbosityLevel < 0){
         stop("detectEvents: verbosityLevel too small, minimum is 0")
     }
-
+    # if(any(is.na(x))){
+    #     stop("detectEvents: x contains NAs. Kindly choose appropriate dataPreparators")
+    # }
 
     classification <- NULL
     Event <- rep(FALSE,windowSize)
@@ -126,11 +133,30 @@ detectEvents <- function(x,
                 print(paste0("EDS is working on index: ",index + nIterationsRefit))
             }
         }
-        edModel <- buildEDModel(x[index:(index + windowSize),,drop=FALSE],dataPrepators,dataPreparationControl,
-                                buildModelAlgo, buildModelControl,
-                                postProcessors, postProcessorControl, ignoreVarianceWarning, edModel)
+        if(is.null(edModel)){
+            modelingData <- x[index:(index + windowSize),,drop=FALSE]
+        }else{
+            modelingData <- x[1:(index + windowSize),,drop=FALSE]
+            eventPositions <- which(edModel$eventHistory)
+# Added by Sowmya to check if eventPositions exists
+if(length(eventPositions>0))
+{
+            modelingData <- modelingData[-eventPositions, , drop = FALSE]
+}
+            modelingData <- modelingData[(nrow(modelingData) - windowSize + 1):nrow(modelingData), , drop=FALSE]
+        }
+        edModel <- buildEDModel(modelingData,dataPrepators,dataPreparationControl,
+                                buildModelAlgo, buildForecastModelControl,buildNeuralNetModelControl,postProcessors, postProcessorControl, ignoreVarianceWarning, edModel)
         newData <- x[(index + windowSize + 1):min(index + windowSize + nIterationsRefit, nrow(x)),,drop=FALSE]
-        p <- predict(edModel,newData)
+## Added by Sowmya
+        if(buildModelAlgo=="NeuralNetwork")
+         {
+        p <- predict.NeuralNetwork(edModel,newData)
+        }
+
+        else{
+            p <- predict(edModel,newData)
+                }
         edModel$eventHistory <- p$eventHistory
         p <- p$lastPredictedEvents
         classification <- rbind(classification, p)
