@@ -9,13 +9,27 @@ getDefaultPreparationControl <- function() {
     )
 }
 
-#' Get Default Control List for ED - Model Building Algorithms
+#' Get Default Control List for ED - Forecast Model Building Algorithms
 #'
 #' @return defaultControlList List with named arguments, 1 for each default parameter
 #' @keywords internal
-getDefaultModelControl <- function() {
+getDefaultForecastModelControl <- function() {
     defaultControlList <- list(
+    )
+}
 
+#' Get Default Control List for ED - NN Model Building Algorithms
+#'
+#' @return defaultControlList List with named arguments, 1 for each default parameter
+#' @keywords internal
+getDefaultNeuralNetModelControl <- function() {
+    defaultControlList <- list(
+        hidden = 1,
+        algorithm="rprop+",
+        threshold=0.01,
+        stepmax=1e+05,
+        linear.output=TRUE,
+        rep=1
     )
 }
 
@@ -25,7 +39,7 @@ getDefaultModelControl <- function() {
 #' @keywords internal
 getDefaultPostControl <- function() {
     defaultControlList <- list(
-        nStandardDeviationsEventThreshhold = 2,
+        nStandardDeviationseventThreshold = 2,
         eventThreshold = .7,
         bedWindowSize = 30
     )
